==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Nessun messaggio sul forum',

	// B
	'bouton_radio_articles_futurs' => 'solo agli articoli inseriti dopo questa modifica (nessuna modifica al database attuale).',
	'bouton_radio_articles_tous' => 'a tutti gli articoli senza eccezioni.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a tutti gli articoli salvo quelli per cui il forum è disattivato.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrazione obbligatoria (gli utenti devono abbonarsi fornendo il loro indirizzo email prima di poter inviare contributi).',
	'bouton_radio_moderation_priori' => 'Moderazione a priori (i
contributi saranno pubblicati dopo validazione da parte degli
amministratori).',
	'bouton_radio_modere_abonnement' => 'solo su abbonamento',
	'bouton_radio_modere_posteriori' => 'moderato a posteriori',
	'bouton_radio_modere_priori' => 'moderato a priori',
	'bouton_radio_publication_immediate' => 'Pubblicazione immediata dei messaggi
(i contributi sono pubblicati subito dopo il loro invio, gli amministratori possono
cancellarli successivamente).',

	// D
	'documents_interdits_forum' => 'Documenti vietati nel forum',

	// E
	'erreur_enregistrement_message' => 'Il tuo messaggio non può essere salvato a causa di un problema tecnico.',
	'extensions_autorisees' => 'Estensioni autorizzate :',
	'extensions_autorisees_toutes' => 'tutto',

	// F
	'form_pet_message_commentaire' => 'Un messaggio, un commento?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Non hai accesso a questi forum.',
	'forum_attention_dix_caracteres' => '<b>Attenzione!</b> il messaggio deve contenere almeno dieci caratteri.',
	'forum_attention_message_non_poste' => 'Attenzione, non puoi postare il tuo messaggio!',
	'forum_attention_nb_caracteres_mini' => '<b>Attenzione!</b> Il vostro messaggio deve contenere almeno @min@ caratteri.',
	'forum_attention_trois_caracteres' => '<b>Attenzione!</b> il titolo deve contenere almeno tre caratteri.',
	'forum_attention_trop_caracteres' => '<b>Attenzione!</b> il messaggio è troppo lungo (@compte@ caratteri): per poter essere registrato esso non deve essere più lungo di @max@ caratteri.',
	'forum_avez_selectionne' => 'Hai selezionato:',
	'forum_cliquer_retour' => 'Clicca <a href=\'@retour_forum@\'>qui</a> per continuare.',
	'forum_envoyer' => 'Invia',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Questo forum è moderato a priori: il tuo contributo apparirà solo dopo essere stato approvato da un amministratore del sito.',
	'forum_lien_hyper' => 'Link ipertestuale',
	'forum_message' => 'I tuoi messaggi',
	'forum_message_definitif' => 'Messaggio definitivo: invialo al sito',
	'forum_message_trop_long' => 'Il tuo messaggio è troppo lungo. La dimensione massima è di 20000 caratteri.',
	'forum_ne_repondez_pas' => 'Non rispondere a questa email ma intervieni sul forum all’indirizzo seguente:',
	'forum_page_url' => '(Se il tuo messaggio si riferisce ad un articolo pubblicato sul Web o ad una pagina contenente maggiori informazioni, è possibile indicare di seguito il titolo della pagina ed il suo indirizzo URL.)',
	'forum_permalink' => 'Permalink al commento',
	'forum_poste_par' => 'Messaggio inviato da @parauteur@ in calce all’articolo "@titre@".',
	'forum_poste_par_court' => 'Messaggio inviato @parauteur@.',
	'forum_poste_par_generique' => 'Messaggio inviato @parauteur@ (@objet@ "@titre@").',
	'forum_qui_etes_vous' => 'Chi sei?',
	'forum_saisie_texte_info' => 'Questo form accetta scorciatoie di SPIP <code>[-&gt;url] {{bold}} {italic} &lt;quote&gt; &lt;code&gt;</code> e il codice HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Per creare un paragrafo lasciate semplicemente una riga vuota.',
	'forum_texte' => 'Testo del messaggio',
	'forum_titre' => 'Titolo',
	'forum_url' => 'URL',
	'forum_valider' => 'Conferma la scelta',
	'forum_voir_avant' => 'Vedi il messaggio prima di inviarlo',
	'forum_votre_email' => 'Indirizzo email',
	'forum_votre_nom' => 'Nome',
	'forum_vous_enregistrer' => 'È necessario iscriversi
per partecipare a questo forum.  Indica qui sotto l’ID personale
che ti è stato fornito.  Se non sei registrato, devi',
	'forum_vous_inscrire' => 'prima iscriverti.',

	// I
	'icone_bruler_message' => 'Segnala come SPAM',
	'icone_bruler_messages' => 'Segnala come SPAM',
	'icone_legitimer_message' => 'Segnala come illegale',
	'icone_poster_message' => 'Invia un messaggio',
	'icone_suivi_forum' => 'Andamento del forum pubblico: @nb_forums@ contributi',
	'icone_suivi_forums' => 'Gestione dei forum',
	'icone_supprimer_message' => 'Elimina il messaggio',
	'icone_supprimer_messages' => 'Cancella questi messaggi',
	'icone_valider_message' => 'Convalida il messaggio',
	'icone_valider_messages' => 'Velida questi messaggi',
	'icone_valider_repondre_message' => 'Conferma e rispondi a questo messaggio',
	'info_1_message_forum' => '1 messaggio nel forum',
	'info_activer_forum_public' => 'Per attivare i forum pubblici, scegli il tipo di moderazione predefinito:',
	'info_appliquer_choix_moderation' => 'Questa scelta di moderazione verrà applicata:',
	'info_config_forums_prive' => 'Nell’area riservata del sito è possibile attivare diversi tipi di forum:',
	'info_config_forums_prive_admin' => 'Un forum riservato agli amministratori del sito:',
	'info_config_forums_prive_global' => 'Un forum globale, aperto a tutti i redattori:',
	'info_config_forums_prive_objets' => 'Un forum per ogni articolo, breve, sito repertoriato, ecc.:',
	'info_desactiver_forum_public' => 'Disattiva l’uso dei forum pubblici.
I forum pubblici potranno essere autorizzati di volta in volta
sui singoli articoli; saranno invece proibiti nelle rubriche, nelle brevi, ecc',
	'info_envoi_forum' => 'Notifica dei forum agli autori degli articoli',
	'info_fonctionnement_forum' => 'Funzionamento del forum:',
	'info_forcer_previsualisation_court' => 'Mostra un’anteprima',
	'info_forcer_previsualisation_long' => 'Mostra un’anteprima prima di inviare un messaggio',
	'info_forums_liees_mot' => 'Messaggi del forum collegati a questa parola chiave',
	'info_gauche_suivi_forum_2' => 'La pagina di <i>monitoraggio dei forum</i> è uno strumento di gestione del sito e non uno spazio di discussione o di redazione. In essa sono pubblicati tutti i contributi dei forum del sito, sia quelli del sito pubblico che quelli dell’area riservata, permettendone la gestione.',
	'info_liens_syndiques_3' => 'forum',
	'info_liens_syndiques_4' => 'sono',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'è',
	'info_liens_syndiques_7' => 'in attesa di convalida',
	'info_liens_texte' => 'Collegamenti nel testo del messaggio',
	'info_liens_titre' => 'Collegamenti nel titolo del messaggio',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modo di funzionamento predefinito dei forum pubblici',
	'info_nb_messages_forum' => '@nb@ messaggi nel forum',
	'info_option_email' => 'Quando un visitatore del sito inserisce un nuovo messaggio nel forumassociato a un articolo, gli autori di quest’ultimo possono essereavvertiti via email. Per ogni tipo di forum, indica se desideri utilizzare quest’opzione.',
	'info_pas_de_forum' => 'nessun forum',
	'info_question_visiteur_ajout_document_forum' => 'Se si desidera autorizzare i visitatori ad allegare dei documenti (immagini, musiche, ecc.) ai propri messaggi nel forum, indicare qui sotto l’elenco delle estensioni dei documenti autorizzati per i forum (per es.: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Se si desidera autorizzare tutti i tipi di documenti considerati affidabili da SPIP, mettere un asterisco. Per non autorizzare nulla lasciate il campo vuoto.',
	'info_selectionner_message' => 'Selezionare i messaggi:',
	'interface_formulaire' => 'Interfaccia form',
	'interface_onglets' => 'Interfaccia a tab',
	'item_activer_forum_administrateur' => 'Attiva il forum degli amministratori',
	'item_config_forums_prive_global' => 'Attiva i forum dei redattori',
	'item_config_forums_prive_objets' => 'Attiva questi forum',
	'item_desactiver_forum_administrateur' => 'Disattiva il forum degli amministratori',
	'item_non_config_forums_prive_global' => 'Disattiva i forum dei redattori',
	'item_non_config_forums_prive_objets' => 'Disattiva questi forum',

	// L
	'label_selectionner' => 'Selezionare :',
	'lien_reponse_article' => 'Risposta all’articolo',
	'lien_reponse_breve_2' => 'Risposta alla breve',
	'lien_reponse_message' => 'Rispondi al messaggio',
	'lien_reponse_rubrique' => 'Risposta alla rubrica',
	'lien_reponse_site_reference' => 'Commenti su questo sito',
	'lien_vider_selection' => 'Selezione vuota',

	// M
	'messages_aucun' => 'Nessuno',
	'messages_meme_auteur' => 'Tutti i messaggi di questo autore',
	'messages_meme_email' => 'Tutti i messaggi da questa email',
	'messages_meme_ip' => 'Tutti i messaggi da questo IP',
	'messages_off' => 'Cancellati',
	'messages_perso' => 'Personale',
	'messages_privadm' => 'Amministratori',
	'messages_prive' => 'Privato',
	'messages_privoff' => 'Cancellati',
	'messages_privrac' => 'Generale',
	'messages_prop' => 'Proposto',
	'messages_publie' => 'Pubblicato',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Tutto',

	// O
	'onglet_messages_internes' => 'Messaggi interni',
	'onglet_messages_publics' => 'Messaggi pubblici',
	'onglet_messages_vide' => 'Messaggi senza testo',

	// R
	'repondre_message' => 'Rispondere al messaggio',

	// S
	'statut_off' => 'Cancellato',
	'statut_original' => 'originale',
	'statut_prop' => 'Proposto',
	'statut_publie' => 'Pubblicato',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Non esitare ad esprimere il tuo punto di vista nel forum di questo articolo (a fondo pagina).',
	'texte_en_cours_validation' => 'Articoli, brevi, forum sottostanti sono proposti per la pubblicazione',
	'texte_en_cours_validation_forum' => 'Non esitare ad esprimere il tuo punto di vista utilizzando i forum ad essi dedicati.',
	'texte_messages_publics' => 'Messaggi pubblici su:',
	'titre_cadre_forum_administrateur' => 'Forum privato degli amministratori',
	'titre_cadre_forum_interne' => 'Forum interno',
	'titre_config_forums_prive' => 'Forum dell’area riservata',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Monitoraggio dei forum',
	'titre_page_forum_suivi' => 'Monitoraggio dei forum',
	'titre_selection_action' => 'Selezione',
	'tout_voir' => 'Vedi tutti i messaggi',

	// V
	'voir_messages_objet' => 'vedi il messaggio',
];

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Nessun messaggio sul forum',

	// B
	'bouton_radio_articles_futurs' => 'solo agli articoli inseriti dopo questa modifica (nessuna modifica al database attuale).',
	'bouton_radio_articles_tous' => 'a tutti gli articoli senza eccezioni.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a tutti gli articoli salvo quelli per cui il forum è disattivato.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrazione obbligatoria (gli utenti devono abbonarsi fornendo il loro indirizzo email prima di poter inviare contributi).', # MODIF
	'bouton_radio_moderation_priori' => 'Moderazione a priori (i
contributi saranno pubblicati dopo validazione da parte degli
amministratori).', # MODIF
	'bouton_radio_modere_abonnement' => 'solo su abbonamento',
	'bouton_radio_modere_posteriori' => 'moderato a posteriori',
	'bouton_radio_modere_priori' => 'moderato a priori',
	'bouton_radio_publication_immediate' => 'Pubblicazione immediata dei messaggi
(i contributi sono pubblicati subito dopo il loro invio, gli amministratori possono
cancellarli successivamente).', # MODIF

	// D
	'documents_interdits_forum' => 'Documenti vietati nel forum',

	// E
	'erreur_enregistrement_message' => 'Il tuo messaggio non può essere salvato a causa di un problema tecnico.',
	'extensions_autorisees' => 'Estensioni autorizzate :',
	'extensions_autorisees_toutes' => 'tutto',

	// F
	'form_pet_message_commentaire' => 'Un messaggio, un commento?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Non hai accesso a questi forum.',
	'forum_attention_dix_caracteres' => '<b>Attenzione!</b> il messaggio deve contenere almeno dieci caratteri.',
	'forum_attention_message_non_poste' => 'Attenzione, non puoi postare il tuo messaggio!',
	'forum_attention_nb_caracteres_mini' => '<b>Attenzione!</b> Il vostro messaggio deve contenere almeno @min@ caratteri.',
	'forum_attention_trois_caracteres' => '<b>Attenzione!</b> il titolo deve contenere almeno tre caratteri.',
	'forum_attention_trop_caracteres' => '<b>Attenzione!</b> il messaggio è troppo lungo (@compte@ caratteri): per poter essere registrato esso non deve essere più lungo di @max@ caratteri.',
	'forum_avez_selectionne' => 'Hai selezionato:',
	'forum_cliquer_retour' => 'Clicca <a href=\'@retour_forum@\'>qui</a> per continuare.',
	'forum_envoyer' => 'Invia',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Questo forum è moderato a priori: il tuo contributo apparirà solo dopo essere stato approvato da un amministratore del sito.', # MODIF
	'forum_lien_hyper' => 'Link ipertestuale',
	'forum_message' => 'I tuoi messaggi',
	'forum_message_definitif' => 'Messaggio definitivo: invialo al sito',
	'forum_message_trop_long' => 'Il tuo messaggio è troppo lungo. La dimensione massima è di 20000 caratteri.',
	'forum_ne_repondez_pas' => 'Non rispondere a questa email ma intervieni sul forum all’indirizzo seguente:',
	'forum_page_url' => '(Se il tuo messaggio si riferisce ad un articolo pubblicato sul Web o ad una pagina contenente maggiori informazioni, è possibile indicare di seguito il titolo della pagina ed il suo indirizzo URL.)',
	'forum_permalink' => 'Permalink al commento',
	'forum_poste_par' => 'Messaggio inviato da @parauteur@ in calce all’articolo "@titre@".',
	'forum_poste_par_court' => 'Messaggio inviato @parauteur@.',
	'forum_poste_par_generique' => 'Messaggio inviato @parauteur@ (@objet@ "@titre@").',
	'forum_qui_etes_vous' => 'Chi sei?',
	'forum_saisie_texte_info' => 'Questo form accetta scorciatoie di SPIP <code>[-&gt;url] {{bold}} {italic} &lt;quote&gt; &lt;code&gt;</code> e il codice HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Per creare un paragrafo lasciate semplicemente una riga vuota.',
	'forum_texte' => 'Testo del messaggio',
	'forum_titre' => 'Titolo',
	'forum_url' => 'URL',
	'forum_valider' => 'Conferma la scelta',
	'forum_voir_avant' => 'Vedi il messaggio prima di inviarlo',
	'forum_votre_email' => 'Indirizzo email',
	'forum_votre_nom' => 'Nome',
	'forum_vous_enregistrer' => 'È necessario iscriversi
per partecipare a questo forum.  Indica qui sotto l’ID personale
che ti è stato fornito.  Se non sei registrato, devi',
	'forum_vous_inscrire' => 'prima iscriverti.',

	// I
	'icone_bruler_message' => 'Segnala come SPAM',
	'icone_bruler_messages' => 'Segnala come SPAM',
	'icone_legitimer_message' => 'Segnala come illegale',
	'icone_poster_message' => 'Invia un messaggio',
	'icone_suivi_forum' => 'Andamento del forum pubblico: @nb_forums@ contributi',
	'icone_suivi_forums' => 'Gestione dei forum',
	'icone_supprimer_message' => 'Elimina il messaggio',
	'icone_supprimer_messages' => 'Cancella questi messaggi',
	'icone_valider_message' => 'Convalida il messaggio',
	'icone_valider_messages' => 'Velida questi messaggi',
	'icone_valider_repondre_message' => 'Conferma e rispondi a questo messaggio',
	'info_1_message_forum' => '1 messaggio nel forum',
	'info_activer_forum_public' => 'Per attivare i forum pubblici, scegli il tipo di moderazione predefinito:',
	'info_appliquer_choix_moderation' => 'Questa scelta di moderazione verrà applicata:',
	'info_config_forums_prive' => 'Nell’area riservata del sito è possibile attivare diversi tipi di forum:',
	'info_config_forums_prive_admin' => 'Un forum riservato agli amministratori del sito:', # MODIF
	'info_config_forums_prive_global' => 'Un forum globale, aperto a tutti i redattori:', # MODIF
	'info_config_forums_prive_objets' => 'Un forum per ogni articolo, breve, sito repertoriato, ecc.:',
	'info_desactiver_forum_public' => 'Disattiva l’uso dei forum pubblici.
I forum pubblici potranno essere autorizzati di volta in volta
sui singoli articoli; saranno invece proibiti nelle rubriche, nelle brevi, ecc',
	'info_envoi_forum' => 'Notifica dei forum agli autori degli articoli', # MODIF
	'info_fonctionnement_forum' => 'Funzionamento del forum:',
	'info_forcer_previsualisation_court' => 'Mostra un’anteprima',
	'info_forcer_previsualisation_long' => 'Mostra un’anteprima prima di inviare un messaggio',
	'info_forums_liees_mot' => 'Messaggi del forum collegati a questa parola chiave',
	'info_gauche_suivi_forum_2' => 'La pagina di <i>monitoraggio dei forum</i> è uno strumento di gestione del sito e non uno spazio di discussione o di redazione. In essa sono pubblicati tutti i contributi dei forum del sito, sia quelli del sito pubblico che quelli dell’area riservata, permettendone la gestione.',
	'info_liens_syndiques_3' => 'forum',
	'info_liens_syndiques_4' => 'sono',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'è',
	'info_liens_syndiques_7' => 'in attesa di convalida',
	'info_liens_texte' => 'Collegamenti nel testo del messaggio',
	'info_liens_titre' => 'Collegamenti nel titolo del messaggio',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modo di funzionamento predefinito dei forum pubblici',
	'info_nb_messages_forum' => '@nb@ messaggi nel forum',
	'info_option_email' => 'Quando un visitatore del sito inserisce un nuovo messaggio nel forumassociato a un articolo, gli autori di quest’ultimo possono essereavvertiti via email. Per ogni tipo di forum, indica se desideri utilizzare quest’opzione.', # MODIF
	'info_pas_de_forum' => 'nessun forum',
	'info_question_visiteur_ajout_document_forum' => 'Se si desidera autorizzare i visitatori ad allegare dei documenti (immagini, musiche, ecc.) ai propri messaggi nel forum, indicare qui sotto l’elenco delle estensioni dei documenti autorizzati per i forum (per es.: gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Se si desidera autorizzare tutti i tipi di documenti considerati affidabili da SPIP, mettere un asterisco. Per non autorizzare nulla lasciate il campo vuoto.',
	'info_selectionner_message' => 'Selezionare i messaggi:',
	'interface_formulaire' => 'Interfaccia form',
	'interface_onglets' => 'Interfaccia a tab',
	'item_activer_forum_administrateur' => 'Attiva il forum degli amministratori', # MODIF
	'item_config_forums_prive_global' => 'Attiva i forum dei redattori', # MODIF
	'item_config_forums_prive_objets' => 'Attiva questi forum',
	'item_desactiver_forum_administrateur' => 'Disattiva il forum degli amministratori', # MODIF
	'item_non_config_forums_prive_global' => 'Disattiva i forum dei redattori', # MODIF
	'item_non_config_forums_prive_objets' => 'Disattiva questi forum',

	// L
	'label_selectionner' => 'Selezionare :',
	'lien_reponse_article' => 'Risposta all’articolo',
	'lien_reponse_breve_2' => 'Risposta alla breve',
	'lien_reponse_message' => 'Rispondi al messaggio',
	'lien_reponse_rubrique' => 'Risposta alla rubrica',
	'lien_reponse_site_reference' => 'Commenti su questo sito',
	'lien_vider_selection' => 'Selezione vuota',

	// M
	'messages_aucun' => 'Nessuno',
	'messages_meme_auteur' => 'Tutti i messaggi di questo autore', # MODIF
	'messages_meme_email' => 'Tutti i messaggi da questa email',
	'messages_meme_ip' => 'Tutti i messaggi da questo IP',
	'messages_off' => 'Cancellati',
	'messages_perso' => 'Personale',
	'messages_privadm' => 'Amministratori', # MODIF
	'messages_prive' => 'Privato',
	'messages_privoff' => 'Cancellati',
	'messages_privrac' => 'Generale',
	'messages_prop' => 'Proposto',
	'messages_publie' => 'Pubblicato',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Tutto',

	// O
	'onglet_messages_internes' => 'Messaggi interni',
	'onglet_messages_publics' => 'Messaggi pubblici',
	'onglet_messages_vide' => 'Messaggi senza testo',

	// R
	'repondre_message' => 'Rispondere al messaggio',

	// S
	'statut_off' => 'Cancellato',
	'statut_original' => 'originale',
	'statut_prop' => 'Proposto',
	'statut_publie' => 'Pubblicato',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Non esitare ad esprimere il tuo punto di vista nel forum di questo articolo (a fondo pagina).',
	'texte_en_cours_validation' => 'Articoli, brevi, forum sottostanti sono proposti per la pubblicazione',
	'texte_en_cours_validation_forum' => 'Non esitare ad esprimere il tuo punto di vista utilizzando i forum ad essi dedicati.',
	'texte_messages_publics' => 'Messaggi pubblici su:',
	'titre_cadre_forum_administrateur' => 'Forum privato degli amministratori', # MODIF
	'titre_cadre_forum_interne' => 'Forum interno',
	'titre_config_forums_prive' => 'Forum dell’area riservata',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Monitoraggio dei forum',
	'titre_page_forum_suivi' => 'Monitoraggio dei forum',
	'titre_selection_action' => 'Selezione',
	'tout_voir' => 'Vedi tutti i messaggi',

	// V
	'voir_messages_objet' => 'vedi il messaggio',
];
